// DO NOT EDIT -- generated by mk-ops
#if !defined (octave_mx_fm_fcdm_h)
#define octave_mx_fm_fcdm_h 1
#include "fCMatrix.h"
#include "fMatrix.h"
#include "fCDiagMatrix.h"
#include "mx-op-decl.h"
MDM_BIN_OP_DECLS (FloatComplexMatrix, FloatMatrix, FloatComplexDiagMatrix, OCTAVE_API)
#endif
