// DO NOT EDIT -- generated by mk-ops
#if !defined (octave_mx_fcm_fs_h)
#define octave_mx_fcm_fs_h 1
#include "fCMatrix.h"
#include "mx-op-decl.h"
MS_BIN_OP_DECLS (FloatComplexMatrix, FloatComplexMatrix, float, OCTAVE_API)
MS_CMP_OP_DECLS (FloatComplexMatrix, float, OCTAVE_API)
MS_BOOL_OP_DECLS (FloatComplexMatrix, float, OCTAVE_API)
#endif
