if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib64/octave/3.6.4 ; rm -rf libcruft.so.1 )
( cd usr/lib64/octave/3.6.4 ; ln -sf libcruft.so.1.0.1 libcruft.so.1 )
( cd usr/lib64/octave/3.6.4 ; rm -rf liboctave.so.1 )
( cd usr/lib64/octave/3.6.4 ; ln -sf liboctave.so.1.1.0 liboctave.so.1 )
( cd usr/lib64/octave/3.6.4 ; rm -rf liboctave.so )
( cd usr/lib64/octave/3.6.4 ; ln -sf liboctave.so.1.1.0 liboctave.so )
( cd usr/lib64/octave/3.6.4 ; rm -rf libcruft.so )
( cd usr/lib64/octave/3.6.4 ; ln -sf libcruft.so.1.0.1 libcruft.so )
( cd usr/lib64/octave/3.6.4 ; rm -rf liboctinterp.so.1 )
( cd usr/lib64/octave/3.6.4 ; ln -sf liboctinterp.so.1.0.2 liboctinterp.so.1 )
( cd usr/lib64/octave/3.6.4 ; rm -rf liboctinterp.so )
( cd usr/lib64/octave/3.6.4 ; ln -sf liboctinterp.so.1.0.2 liboctinterp.so )
( cd usr/bin ; rm -rf octave-config )
( cd usr/bin ; ln -sf octave-config-3.6.4 octave-config )
( cd usr/bin ; rm -rf mkoctfile )
( cd usr/bin ; ln -sf mkoctfile-3.6.4 mkoctfile )
( cd usr/bin ; rm -rf octave )
( cd usr/bin ; ln -sf octave-3.6.4 octave )
