// DO NOT EDIT -- generated by mk-ops
#if !defined (octave_mx_cdm_dm_h)
#define octave_mx_cdm_dm_h 1
#include "CDiagMatrix.h"
#include "dDiagMatrix.h"
#include "mx-op-decl.h"
DMDM_BIN_OP_DECLS (ComplexDiagMatrix, ComplexDiagMatrix, DiagMatrix, OCTAVE_API)
#endif
