// DO NOT EDIT -- generated by mk-ops
#if !defined (octave_vx_cv_ccv_h)
#define octave_vx_cv_ccv_h 1
#include "CColVector.h"
#include "dColVector.h"
#include "mx-op-decl.h"
VV_BIN_OP_DECLS (ComplexColumnVector, ColumnVector, ComplexColumnVector, OCTAVE_API)
#endif
