// DO NOT EDIT -- generated by mk-ops
#if !defined (octave_mx_fs_fcm_h)
#define octave_mx_fs_fcm_h 1
#include "fCMatrix.h"
#include "mx-op-decl.h"
SM_BIN_OP_DECLS (FloatComplexMatrix, float, FloatComplexMatrix, OCTAVE_API)
SM_CMP_OP_DECLS (float, FloatComplexMatrix, OCTAVE_API)
SM_BOOL_OP_DECLS (float, FloatComplexMatrix, OCTAVE_API)
#endif
