// DO NOT EDIT -- generated by mk-ops
#if !defined (octave_vx_frv_fcrv_h)
#define octave_vx_frv_fcrv_h 1
#include "fCRowVector.h"
#include "fRowVector.h"
#include "mx-op-decl.h"
VV_BIN_OP_DECLS (FloatComplexRowVector, FloatRowVector, FloatComplexRowVector, OCTAVE_API)
#endif
