// DO NOT EDIT -- generated by mk-ops
#if !defined (octave_vx_fs_fcrv_h)
#define octave_vx_fs_fcrv_h 1
#include "fCRowVector.h"
#include "mx-op-decl.h"
SV_BIN_OP_DECLS (FloatComplexRowVector, float, FloatComplexRowVector, OCTAVE_API)
#endif
