// DO NOT EDIT -- generated by mk-ops
#if !defined (octave_mx_fnda_ui16_h)
#define octave_mx_fnda_ui16_h 1
#include "uint16NDArray.h"
#include "fNDArray.h"
#include "oct-inttypes.h"
#include "mx-op-decl.h"
NDS_BIN_OP_DECLS (uint16NDArray, FloatNDArray, octave_uint16, OCTAVE_API)
NDS_CMP_OP_DECLS (FloatNDArray, octave_uint16, OCTAVE_API)
NDS_BOOL_OP_DECLS (FloatNDArray, octave_uint16, OCTAVE_API)
#endif
