// DO NOT EDIT -- generated by mk-ops
#if !defined (octave_mx_fdm_fm_h)
#define octave_mx_fdm_fm_h 1
#include "fMatrix.h"
#include "fDiagMatrix.h"
#include "mx-op-decl.h"
DMM_BIN_OP_DECLS (FloatMatrix, FloatDiagMatrix, FloatMatrix, OCTAVE_API)
#endif
