// DO NOT EDIT -- generated by mk-ops
#if !defined (octave_mx_nda_ui32_h)
#define octave_mx_nda_ui32_h 1
#include "uint32NDArray.h"
#include "dNDArray.h"
#include "oct-inttypes.h"
#include "mx-op-decl.h"
NDS_BIN_OP_DECLS (uint32NDArray, NDArray, octave_uint32, OCTAVE_API)
NDS_CMP_OP_DECLS (NDArray, octave_uint32, OCTAVE_API)
NDS_BOOL_OP_DECLS (NDArray, octave_uint32, OCTAVE_API)
#endif
