// DO NOT EDIT -- generated by mk-ops
#if !defined (octave_mx_fdm_fcm_h)
#define octave_mx_fdm_fcm_h 1
#include "fCMatrix.h"
#include "fDiagMatrix.h"
#include "mx-op-decl.h"
DMM_BIN_OP_DECLS (FloatComplexMatrix, FloatDiagMatrix, FloatComplexMatrix, OCTAVE_API)
#endif
