// DO NOT EDIT -- generated by mk-ops
#if !defined (octave_mx_i32_fnda_h)
#define octave_mx_i32_fnda_h 1
#include "int32NDArray.h"
#include "oct-inttypes.h"
#include "fNDArray.h"
#include "mx-op-decl.h"
SND_BIN_OP_DECLS (int32NDArray, octave_int32, FloatNDArray, OCTAVE_API)
SND_CMP_OP_DECLS (octave_int32, FloatNDArray, OCTAVE_API)
SND_BOOL_OP_DECLS (octave_int32, FloatNDArray, OCTAVE_API)
#endif
